/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/**
 * Main include file for the Bonobo component model UI section
 *
 * Authors:
 *   Miguel de Icaza (miguel@ximian.com)
 *   Michael Meeks   (michael@ximian.com)
 *
 * Copyright 2001 Ximian, Inc.
 */
#ifndef LIBBONOBOUI_H
#define LIBBONOBOUI_H 1

#include <libbonobo.h>

G_BEGIN_DECLS

#include <bonobo/bonobo-widget.h>
#include <bonobo/bonobo-control.h>
#include <bonobo/bonobo-control-frame.h>
#include <bonobo/bonobo-property-control.h>

#include <bonobo/bonobo-window.h>
#include <bonobo/bonobo-ui-main.h>
#include <bonobo/bonobo-ui-util.h>
#include <bonobo/bonobo-ui-component.h>
#include <bonobo/bonobo-ui-container.h>

#include <bonobo/bonobo-selector.h>
#include <bonobo/bonobo-file-selector-util.h>

#include <bonobo/bonobo-canvas-item.h>
#include <bonobo/bonobo-canvas-component.h>

#include <bonobo/bonobo-zoomable.h>
#include <bonobo/bonobo-zoomable-frame.h>

#include <bonobo/bonobo-dock-item.h>
#include <bonobo/bonobo-dock.h>
#include <bonobo/bonobo-ui-engine.h>
#include <bonobo/bonobo-ui-toolbar-item.h>
#include <bonobo/bonobo-ui-toolbar.h>

#include <bonobo/bonobo-ui-type-builtins.h>

G_END_DECLS

#endif /* LIBBONOBOUI_H */
